require 'date'
require 'thor'
require 'thor/runner'

module Parsefiles
  module CLI
    class Main < Thor

      desc 'version', 'Version of the Merge utility'
      def version
        require 'parsefiles/version'
        say Parsefiles::VERSION
      end

      desc 'find', 'Find expression within specified text files'
      long_desc <<-LONGDESC
        Examples:
        \x5 parsefiles find -d 2 -p simpson ./
        \x5 => Search the current folder starting 2 days back for simpson.
        \x5\x5 parsefiles find -s 08-01-2014 -e 08-03-2014 -p simpson ./
        \x5 => Search between the 2 given dates for simpson
        \x5\x5 parsefiles find -p simpson ./ /tmp/
        \x5=> Search the current folder and tmp folder for simpson with today's date.
      LONGDESC
      method_option :days_back, aliases: '-d', type: 'string', default: '1', desc: 'number of days back to search'
      method_option :start_date, aliases: '-s', type: 'string', default: Date.today.strftime('%m-%d-%Y'), desc: 'start date to begin file search from'
      method_option :end_date, aliases: '-e', type: 'string', default: Date.today.strftime('%m-%d-%Y'), desc: 'end date to finish file search from'
      method_option :pattern, aliases: '-p', type: 'string', default: ' ', desc: 'pattern to search for', :required => true

      def find(*folders)
        begin
          folders = folders.split unless folders.class == Array
          folders.each do |folder|
            f = Parsefiles::Folders.new(folder,options)
            files = f.get_files_in_range
            files.each do |file|
              puts "================================================"
              puts "Reading : #{file}"
              puts "================================================"
              parse = Parsefiles::FileOps.new(file,options[:pattern])
              parse.parse_file
            end
          end
        rescue Exception => e
          say e.message, :red
        end
      end

    end
  end

end
