require 'date'
require_relative 'utils'

module Parsefiles
  class Folders

    include Utils

    attr_accessor :folder, :files

    VALID_TYPES = "{txt,log,gz}"

    def initialize(folder,options={})
      @folder = check_location(folder)
      @files = get_files_with_date
      @options = options
    end

    def check_location(folder)
      if folder.match(/.*\.log$|txt$|gz$/i)
        "./#{folder}"
      else
        folder = remove_trailing_slash(folder)
        "#{folder}/*."+VALID_TYPES
      end
    end

    def remove_trailing_slash(folder)
      folder.gsub(/(.*)\/$/,'\1')
    end

    def get_files_in_range
      start_date = get_start_date
      end_date = get_end_date

      result = []
      @files.each_with_index do |file,index|
        result << file[0] if Folders.date_in_range(file[1],start_date,end_date)
      end
      result
    end

    def get_start_date
      if @options["days_back"].to_i > 1
        days_back
      else
        start_date
      end
    end

    def get_end_date
      Folders.validate_date_format(@options["end_date"])
      @options["end_date"] if @options["end_date"]
    end

    def calc_start_date(days_back)
      date = Date.today - days_back
      date.strftime('%m-%d-%Y')
    end

    private

    def days_back
      calc_start_date(@options[:days_back].to_i)
    end

    def start_date
      Folders.validate_date_format(@options["start_date"])
      @options["start_date"] if @options["start_date"]
    end

    # Returns an array with file and date in unix time format ['file.txt','40001245']
    def get_files_with_date
      file_list = Dir.glob(@folder)
      result = []
      file_list.reduce([]) do |file_stats,file|
        file_stats = Array.new
        file_stats << file
        file_stats << Folders.unix_ts(file)
        result << file_stats
      end
    end

  end
end
